@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher::Syslog;
 use vars '$VERSION';
-$VERSION = '0.01';
+$VERSION = '0.02';
 use base 'Log::Report::Dispatcher';
 
 use Sys::Syslog 0.11, qw/:standard :macros/;
@@ -51,7 +51,7 @@ sub init($)
             my @reasons = expand_reasons $reasons;
 
             my $prio    = Sys::Syslog::xlate($level);
-            error __"syslog level '$level' not understood"
+            error __x"syslog level '{level}' not understood", level => $level
                 if $prio eq -1;
 
             $self->{prio}{$_} = $prio for @reasons;
